﻿/*
    This example creates a single ListView control with a fixed number of rows.
    The ListView control is adjusted so that all rows and all columns are
    visible.  No scroll bars are shown.
*/
#NoEnv
#SingleInstance Force


/*
    Step 0: Example set up.

    Comments
    --------
    The NumberOfRows variable is used to set the number of rows that will be
    defined for the ListView control.  Change this value to see what happens.
    However, setting the value to anything less than 3 will not generate a
    useful result for this example.
*/
NumberOfRows :=3

gui -DPIScale -MinimizeBox
gui Add,Button,gReload,%A_Space% Rebuild... %A_Space%


/*
    Step 1: Set the font

    Comments
    --------
    If planning to use the default GUI font, this step is optional.  Otherwise,
    the font should be set before the ListView control is created.

    A random font size is used here to show that any font will work.
*/
Random FontSize,8,20
gui Font,s%FontSize%


/*
    Step 2: Create the ListView control

    Comments
    --------
    The hWnd option is necessary because the handle of the ListView control
    will be used by the LVM_ApproximateViewRect function.

    The size (width and height) of the ListView control is set to 0 to ensure
    that the control does not take up any space but it can be set to any value
    or not specified at all.  The final size will be calculated and set later.
    However, any other options should be specified here.  If an image list is
    used, it should be attached to the ListView control before the size is
    calculated.
*/
gui Add,ListView,w0 h0 hWndhLV,Color|Hex


/*
    Step 3: Populate the ListView control

    Comments
    --------
    If the column width can be set without real data (not recommended in most
    cases), this step can be done after the ListView control has been resized.
*/
LV_Add("","Red",0xFF0000)
LV_Add("","Green",0x008000)
LV_Add("","Blue",0x0000FF)


/*
    Step 4: Set the width of the columns

    Comments
    --------
    Note: In most cases, the "AutoHdr" option should not be used for the
    rightmost column because it will define the column width to be whatever
    space that is not used by the other columns.
*/
LV_ModifyCol(1,"AutoHdr")
LV_ModifyCol(2,"Auto")


/*
    Step 5: Calculate the size of the ListView control

    Comments
    --------
    Two important notes.  First of all, note that the p_NumberOfItems parameter
    of the LVM_ApproximateViewRect function is set to the desired number of rows
    minus 1.  This trick will set the height to the exact size needed.  Next,
    note that 4 is added to the width and height return values.  This adjustment
    will ensure that the vertical and/or scroll bars do not show.
*/
LVM_ApproximateViewRect(hLV,NumberOfRows-1,Width,Height)
Width+=4
Height+=4


/*
    Step 5: Resize the ListView control

    Comments
    --------
    ControlMove is used because it is not DPI aware.  The "GUIControl,Move"
    command is more efficient but it cannot (read: should not) be used
    unless the -DPIScale option has been set for the GUI.
*/
;;;;;GUIControl Move,%hLV%,w%Width% h%Height%
ControlMove,,,,Width,Height,ahk_id %hLV%


/*
    Step 99: Show window

    Comments
    --------
    AutoSize is used when showing the window because the size of the ListView
    control has changed after it was created.
*/
SplitPath A_ScriptName,,,,$ScriptTitle
gui Show,AutoSize,%$ScriptTitle%
return


GUIClose:
GUIEscape:
ExitApp


Reload:
Reload
return


;*******************
;*                 *
;*    Functions    *
;*                 *
;*******************
#include LVM_ApproximateViewRect.ahk
