﻿/*
    This example creates a single ListView control with a dynamic number of
    rows. The ListView control is adjusted so that a fixed number of rows and
    all columns are visible.  The vertical scroll bar is showing in most cases.
*/
#NoEnv
#SingleInstance Force

;-- Initialize
StandardColors :={Aqua:"0x00FFFF",Black:"0x000000",Blue:"0x0000FF",Fuchsia:"0xFF00FF",Gray:"0x808080",Green:"0x008000",Lime:"0x00FF00",Maroon:"0x800000",Navy:"0x000080",Olive:"0x808000",Purple:"0x800080",Red:"0xFF0000",Silver:"0xC0C0C0",Teal:"0x008080",White:"0xFFFFFF",Yellow:"0xFFFF00"}
SysGet CXVSCROLL,2
    ;-- Width of a vertical scroll bar, in pixels


/*
    Step 0: Example set up.

    Comments
    --------
    The NumberOfRows variable is used to set the number of rows that will be
    defined for the ListView control.  Change this value to see what happens.
*/
NumberOfRows :=9

gui -DPIScale -MinimizeBox
gui Add,Button,gReload,%A_Space% Rebuild... %A_Space%


/*
    Step 1: Set the font

    Comments
    --------
    If planning to use the default GUI font, this step is optional.  Otherwise,
    the font should be set before the ListView control is created.

    A random font size is used here to show that any font will work.
*/
Random FontSize,8,20
gui Font,s%FontSize%

/*
    Step 2: Create the ListView control

    Comments
    --------
    The hWnd option is necessary because the handle of the ListView control
    will be used by the LVM_ApproximateViewRect function.

    The size (width and height) of the ListView control is set to 0 to ensure
    that the control does not take up any space but it can be set to any value
    or not specified at all.  The final size will be calculated and set later.
    However, any other options should be specified here.  If an image list is
    used, it should be attached to the ListView control before the size is
    calculated.
*/
gui Add,ListView,w0 h0 hWndhLV,Color|Hex


/*
    Step 3: Populate the ListView control

    Comments
    --------
    If the column width can be set without real data (not recommended in most
    cases), this step can be done after the ListView control has been resized.
*/
For Color,Hex in StandardColors
    LV_Add("",Color,Hex)


/*
    Step 4: Set the width of the columns

    Comments
    --------
    Note: In most cases, the "AutoHdr" option should not be used for the
    rightmost column because it will define the column width to be whatever
    space that is not used by the other columns.
*/
LV_ModifyCol(1,"AutoHdr")
LV_ModifyCol(2,"Auto")


/*
    Step 5: Calculate the size of the ListView control

    Comments
    --------
    Two important notes.  First of all, note that the p_NumberOfItems parameter
    of the LVM_ApproximateViewRect function is set to the desired number of rows
    minus 1.  This trick will set the height to the exact size needed.  Next,
    note that 4 is added to the width and height return values.  In addition,
    the width of a vertical scroll bar is added to the width.  These adjustments
    will ensure that the horizontal scroll bar does not show and that the
    vertical scroll bar does not cover any of the rightmost column.
*/
LVM_ApproximateViewRect(hLV,NumberOfRows-1,Width,Height)
Width+=4+CXVSCROLL
Height+=4


/*
    Step 5: Resize the ListView control

    Comments
    --------
    ControlMove is used because it is not DPI aware.  The "GUIControl,Move"
    command is more efficient but it cannot (read: should not) be used
    unless the -DPIScale option has been set for the GUI.
*/
;;;;;GUIControl Move,%hLV%,w%Width% h%Height%
ControlMove,,,,Width,Height,ahk_id %hLV%


/*
    Step 99: Show window

    Comments
    --------
    AutoSize is used when showing the window because the size of the ListView
    control has changed after it was created.
*/
SplitPath A_ScriptName,,,,$ScriptTitle
gui Show,AutoSize,%$ScriptTitle%
return


GUIClose:
GUIEscape:
ExitApp


Reload:
Reload
return


;*******************
;*                 *
;*    Functions    *
;*                 *
;*******************
#include LVM_ApproximateViewRect.ahk
