﻿;------------------------------
;
; Function: LVM_ApproximateViewRect
;
; Description:
;
;    Calculates the approximate width and height required to display a given
;    number of items.
;
; Parameters:
;
;   p_NumberOfItems - The number of items to be displayed in the control.  If
;       set to -1 (the default), the total number of items in the control is
;       used.
;
;   r_Width, r_Height - Output variables. [Optional]
;
; Returns:
;
;   An integer that holds the approximate width (in the LOWORD) and height (in
;   the HIWORD) needed to display the items, in pixels.  To extract these values
;   from the return value, use the following logic:
;
;       (start code)
;       RC:=LVM_ApproximateViewRect(hLV,...)
;       Width:=RC & 0xFFFF     ;-- LOWORD
;       Height:=RC >> 16       ;-- HIWORD
;       (end)
;
;   If the output variables are defined (r_Width and r_Height), the calculated
;   values are returned in these variables.
;
; Observations:
;
;   This message only appears to work with a ListView control in Report mode.
;
;-------------------------------------------------------------------------------
LVM_ApproximateViewRect(hLV,p_NumberOfItems:=-1,ByRef r_Width:="",ByRef r_Height:="")
    {
    Static LVM_APPROXIMATEVIEWRECT:=0x1040              ;-- LVM_FIRST + 64

    ;-- Calculate approximate view
    SendMessage
        ,LVM_APPROXIMATEVIEWRECT
        ,p_NumberOfItems
        ,0
        ,,ahk_id %hLV%

    ;-- Extract values (UShort) and assign to output variables
    r_Width :=ErrorLevel&0xFFFF ;-- LOWORD
    r_Height:=ErrorLevel>>16    ;-- HIWORD
    Return ErrorLevel
    }
